@@ -19,16 +19,12 @@ from django.db import models
 from eggplant import APP_LABEL
 from eggplant.utils.json import json_model_dict
 
-class DictModel(models.Model, dict):
+class DictModel(models.Model):
 
     """
     An abstract model to make Models have dictionary-like interface
     """
 
-    def __iter__(self):
-        for i in self.__class__._meta.fields:
-            yield i
-
     def __getitem__(self, key):
         if key in self.fields:
             return getattr(self, key)
@@ -48,13 +44,13 @@ class DictModel(models.Model, dict):
         return k in self.keys()
 
     def items(self):
-        return [(field.name, self[field.name]) for field in self]
+        return [(field.name, self[field.name]) for field in self.__class__._meta.fields]
 
     def keys(self):
         return self.fields
 
     def values(self):
-        return [self[field.name] for field in self]
+        return [self[field.name] for field in self.__class__._meta.fields]
 
     @property
     def fields(self):
@@ -62,16 +58,22 @@ class DictModel(models.Model, dict):
         :return: a list containing the name of fields in this model
         """
         if not hasattr(self, '_fields') or self._fields is None:
-            self._fields = [field.name for field in self]
+            self._fields = [field.name for field in self.__class__._meta.fields]
         return self._fields
 
-    def dict(self):
+    def dict(self, json_serializable=False, summary=False):
         """Convert a model into dict
         :return: a dictionary containing fields name and values in this model
         """
-        return dict(self.items())
+        if json_serializable:
+            json_serializable_fields = [field.name for field in self.__class__._meta.fields
+                if not isinstance(field, (models.OneToOneField, models.ManyToManyField, models.ForeignKey))]
+            result = dict([item for item in self.items() if item[0] in json_serializable_fields])
+        else:
+            result = dict(self.items())
+        return result
 
-    def json_dict(self, use_float_seconds=True):
+    def json_dict(self, use_float_seconds=True, summary=False):
         """Convert a model into dict which is json serializable.
 
         DateTimeField and DateField will be converted into a unix-timestamp-like object.
@@ -81,7 +83,7 @@ class DictModel(models.Model, dict):
 
         :return: a dictionary which is json serializable
         """
-        return json_model_dict(self.dict(), use_float_seconds=use_float_seconds)
+        return json_model_dict(self.dict(json_serializable=True, summary=summary), use_float_seconds=use_float_seconds)
 
     class Meta:
         abstract = True
