@@ -18,7 +18,7 @@ import json
 from django.conf import settings
 from django.contrib.auth import authenticate, login
 from django.views.decorators.csrf import csrf_exempt
-from eggplant.constants.settings import DEPLOYED, SIGNATURE_KEY_CLASS, AJAX_SIGNATURE_KEY_CLASS
+from eggplant.constants.settings import DEPLOYED, SIGNATURE_KEY_CLASS, AJAX_SIGNATURE_KEY_CLASS, DEFAULT_AUTH_METHOD
 from eggplant.datatype import AttributedDict
 from eggplant.utils import import_from_string
 from eggplant.views import View, exceptions
@@ -37,6 +37,10 @@ class APIView(View):
         return True
 
     def user_authentication_method(self, *args, **kwargs):
+        default_auth_method = getattr(settings, DEFAULT_AUTH_METHOD, None)
+        if default_auth_method is not None:
+            return default_auth_method
+
         if self.init_kwargs.has_key('auth_method'):
             return self.init_kwargs['auth_method']
 
